package com.ruoyi.tuya.service;

import java.util.List;
import com.ruoyi.tuya.domain.TuyaLeaveWords;

/**
 * 用户留言Service接口
 * 
 * @author zf
 * @date 2022-08-23
 */
public interface ITuyaLeaveWordsService 
{
    /**
     * 查询用户留言
     * 
     * @param wordsId 用户留言主键
     * @return 用户留言
     */
    public TuyaLeaveWords selectTuyaLeaveWordsByWordsId(Long wordsId);

    /**
     * 查询用户留言列表
     * 
     * @param tuyaLeaveWords 用户留言
     * @return 用户留言集合
     */
    public List<TuyaLeaveWords> selectTuyaLeaveWordsList(TuyaLeaveWords tuyaLeaveWords);

    /**
     * 新增用户留言
     * 
     * @param tuyaLeaveWords 用户留言
     * @return 结果
     */
    public int insertTuyaLeaveWords(TuyaLeaveWords tuyaLeaveWords);

    /**
     * 修改用户留言
     * 
     * @param tuyaLeaveWords 用户留言
     * @return 结果
     */
    public int updateTuyaLeaveWords(TuyaLeaveWords tuyaLeaveWords);

    /**
     * 批量删除用户留言
     * 
     * @param wordsIds 需要删除的用户留言主键集合
     * @return 结果
     */
    public int deleteTuyaLeaveWordsByWordsIds(Long[] wordsIds);

    /**
     * 删除用户留言信息
     * 
     * @param wordsId 用户留言主键
     * @return 结果
     */
    public int deleteTuyaLeaveWordsByWordsId(Long wordsId);
}
